Documentation
¶
Index ¶
- type Bar
- type Bar3D
- type BaseConfiguration
- func (bc *BaseConfiguration) Accept(visitor ConfigurationVisitor)
- func (bc *BaseConfiguration) AddDataset(dataset ...opts.Dataset)
- func (bc *BaseConfiguration) FillDefaultValues()
- func (bc *BaseConfiguration) GetAssets() opts.Assets
- func (bc *BaseConfiguration) JSON() map[string]interface{}
- func (bc *BaseConfiguration) JSONNotEscaped() template.HTML
- type BaseConfigurationVisitor
- func (b BaseConfigurationVisitor) Visit(chart map[string]interface{})
- func (b BaseConfigurationVisitor) VisitAngleAxis(angleAxis opts.AngleAxis) interface{}
- func (b BaseConfigurationVisitor) VisitAxisPointer(axisPointer *opts.AxisPointer) interface{}
- func (b BaseConfigurationVisitor) VisitBrush(brush opts.Brush) interface{}
- func (b BaseConfigurationVisitor) VisitCalendar(calendar []*opts.Calendar) interface{}
- func (b BaseConfigurationVisitor) VisitDataZooms(dataZooms []opts.DataZoom) interface{}
- func (b BaseConfigurationVisitor) VisitDatasets(datasets ...opts.Dataset) interface{}
- func (b BaseConfigurationVisitor) VisitGeo(geo opts.GeoComponent) interface{}
- func (b BaseConfigurationVisitor) VisitGrid(grid []opts.Grid) interface{}
- func (b BaseConfigurationVisitor) VisitGrid3D(grid3D opts.Grid3D) interface{}
- func (b BaseConfigurationVisitor) VisitLegendOpt(legend opts.Legend) interface{}
- func (b BaseConfigurationVisitor) VisitParallel(parallel opts.ParallelComponent) interface{}
- func (b BaseConfigurationVisitor) VisitParallelAxis(parallelAxes []opts.ParallelAxis) interface{}
- func (b BaseConfigurationVisitor) VisitPolar(polar opts.Polar) interface{}
- func (b BaseConfigurationVisitor) VisitRadar(radar opts.RadarComponent) interface{}
- func (b BaseConfigurationVisitor) VisitRadiusAxis(radiusAxis opts.RadiusAxis) interface{}
- func (b BaseConfigurationVisitor) VisitSeriesOpt(series MultiSeries) interface{}
- func (b BaseConfigurationVisitor) VisitSingleAxis(singleAxis opts.SingleAxis) interface{}
- func (b BaseConfigurationVisitor) VisitTitleOpt(title opts.Title) interface{}
- func (b BaseConfigurationVisitor) VisitToolbox(toolbox opts.Toolbox) interface{}
- func (b BaseConfigurationVisitor) VisitTooltipOpt(tooltip opts.Tooltip) interface{}
- func (b BaseConfigurationVisitor) VisitVisualMaps(visualMaps []opts.VisualMap) interface{}
- func (b BaseConfigurationVisitor) VisitXAxis(xAxis []opts.XAxis) interface{}
- func (b BaseConfigurationVisitor) VisitXAxis3D(xAxis3D opts.XAxis3D) interface{}
- func (b BaseConfigurationVisitor) VisitYAxis(yAxis []opts.YAxis) interface{}
- func (b BaseConfigurationVisitor) VisitYAxis3D(yAxis3D opts.YAxis3D) interface{}
- func (b BaseConfigurationVisitor) VisitZAxis3D(zAxis3D opts.ZAxis3D) interface{}
- type BoxPlot
- type Chart3D
- type ConfigurationVisitor
- type Custom
- type EffectScatter
- type Funnel
- type Gauge
- type Geo
- type GlobalOpts
- func WithAngleAxisOps(opt opts.AngleAxis) GlobalOpts
- func WithAnimation(enable bool) GlobalOpts
- func WithAxisPointerOpts(opt *opts.AxisPointer) GlobalOpts
- func WithBrush(opt opts.Brush) GlobalOpts
- func WithColorsOpts(opt opts.Colors) GlobalOpts
- func WithDataZoomOpts(opt ...opts.DataZoom) GlobalOpts
- func WithEventListeners(listeners ...event.Listener) GlobalOpts
- func WithGeoComponentOpts(opt opts.GeoComponent) GlobalOpts
- func WithGrid3DOpts(opt opts.Grid3D) GlobalOpts
- func WithGridOpts(opt ...opts.Grid) GlobalOpts
- func WithInitializationOpts(opt opts.Initialization) GlobalOpts
- func WithLegendOpts(opt opts.Legend) GlobalOpts
- func WithParallelAxisList(opt []opts.ParallelAxis) GlobalOpts
- func WithParallelComponentOpts(opt opts.ParallelComponent) GlobalOpts
- func WithPolarOps(opt opts.Polar) GlobalOpts
- func WithProgressive(opt int) GlobalOpts
- func WithProgressiveThreshold(opt int) GlobalOpts
- func WithRadarComponentOpts(opt opts.RadarComponent) GlobalOpts
- func WithRadiusAxisOps(opt opts.RadiusAxis) GlobalOpts
- func WithSingleAxisOpts(opt opts.SingleAxis) GlobalOpts
- func WithTitleOpts(opt opts.Title) GlobalOpts
- func WithToolboxOpts(opt opts.Toolbox) GlobalOpts
- func WithTooltipOpts(opt opts.Tooltip) GlobalOpts
- func WithVisualMapOpts(opt ...opts.VisualMap) GlobalOpts
- func WithXAxis3DOpts(opt opts.XAxis3D) GlobalOpts
- func WithXAxisOpts(opt opts.XAxis, index ...int) GlobalOpts
- func WithYAxis3DOpts(opt opts.YAxis3D) GlobalOpts
- func WithYAxisOpts(opt opts.YAxis, index ...int) GlobalOpts
- func WithZAxis3DOpts(opt opts.ZAxis3D) GlobalOpts
- type Graph
- type HeatMap
- type Kline
- type Line
- type Line3D
- type Liquid
- type Map
- type MultiSeries
- type Overlaper
- type Parallel
- type Pie
- type Radar
- type RectAggregator
- type RectChart
- type RectConfiguration
- type Sankey
- type Scatter
- type Scatter3D
- type SeriesOpts
- func WithAnimationOpts(opt opts.Animation) SeriesOpts
- func WithAreaStyleOpts(opt opts.AreaStyle) SeriesOpts
- func WithBar3DChartOpts(opt opts.Bar3DChart) SeriesOpts
- func WithBarChartOpts(opt opts.BarChart) SeriesOpts
- func WithCalendarIndex(index int) SeriesOpts
- func WithCircularStyleOpts(opt opts.CircularStyle) SeriesOpts
- func WithCoordinateSystem(cs string) SeriesOpts
- func WithCustomChartOpts(opt opts.CustomChart) SeriesOpts
- func WithDatasetIndex(index int) SeriesOpts
- func WithEffectScatterChartOpts(opt opts.EffectScatterChart) SeriesOpts
- func WithEmphasisOpts(opt opts.Emphasis) SeriesOpts
- func WithEncodeOpts(opt opts.Encode) SeriesOpts
- func WithGraphChartOpts(opt opts.GraphChart) SeriesOpts
- func WithHeatMapChartOpts(opt opts.HeatMapChart) SeriesOpts
- func WithItemStyleOpts(opt opts.ItemStyle) SeriesOpts
- func WithKlineChartOpts(opt opts.KlineChart) SeriesOpts
- func WithLabelOpts(opt opts.Label) SeriesOpts
- func WithLineChartOpts(opt opts.LineChart) SeriesOpts
- func WithLineStyleOpts(opt opts.LineStyle) SeriesOpts
- func WithLiquidChartOpts(opt opts.LiquidChart) SeriesOpts
- func WithMarkAreaData(datas ...[]opts.MarkAreaData) SeriesOpts
- func WithMarkAreaData0(data0 opts.MarkAreaData0) SeriesOpts
- func WithMarkAreaData1(data1 opts.MarkAreaData1) SeriesOpts
- func WithMarkAreaNameCoordItemOpts(opt ...opts.MarkAreaNameCoordItem) SeriesOpts
- func WithMarkAreaNameTypeItemOpts(opt ...opts.MarkAreaNameTypeItem) SeriesOpts
- func WithMarkAreaNameXAxisItemOpts(opt ...opts.MarkAreaNameXAxisItem) SeriesOpts
- func WithMarkAreaNameYAxisItemOpts(opt ...opts.MarkAreaNameYAxisItem) SeriesOpts
- func WithMarkAreaStyleOpts(opt opts.MarkAreaStyle) SeriesOpts
- func WithMarkLineNameCoordItemOpts(opt ...opts.MarkLineNameCoordItem) SeriesOpts
- func WithMarkLineNameTypeItemOpts(opt ...opts.MarkLineNameTypeItem) SeriesOpts
- func WithMarkLineNameXAxisItemOpts(opt ...opts.MarkLineNameXAxisItem) SeriesOpts
- func WithMarkLineNameYAxisItemOpts(opt ...opts.MarkLineNameYAxisItem) SeriesOpts
- func WithMarkLineStyleOpts(opt opts.MarkLineStyle) SeriesOpts
- func WithMarkPointNameCoordItemOpts(opt ...opts.MarkPointNameCoordItem) SeriesOpts
- func WithMarkPointNameTypeItemOpts(opt ...opts.MarkPointNameTypeItem) SeriesOpts
- func WithMarkPointStyleOpts(opt opts.MarkPointStyle) SeriesOpts
- func WithPieChartOpts(opt opts.PieChart) SeriesOpts
- func WithRadarChartOpts(opt opts.RadarChart) SeriesOpts
- func WithRippleEffectOpts(opt opts.RippleEffect) SeriesOpts
- func WithScatterChartOpts(opt opts.ScatterChart) SeriesOpts
- func WithSeriesAnimation(enable bool) SeriesOpts
- func WithSeriesOpts(opf SingleSeriesOptFunc) SeriesOpts
- func WithSeriesSymbolKeepAspect(enable bool) SeriesOpts
- func WithSunburstOpts(opt opts.SunburstChart) SeriesOpts
- func WithTreeMapOpts(opt opts.TreeMapChart) SeriesOpts
- func WithTreeOpts(opt opts.TreeChart) SeriesOpts
- func WithWorldCloudChartOpts(opt opts.WordCloudChart) SeriesOpts
- type SingleSeries
- type SingleSeriesOptFunc
- type Sunburst
- type Surface3D
- type ThemeRiver
- type Tree
- type TreeMap
- type WordCloud
- type XYAxis
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Bar ¶
type Bar struct {
RectChart
// contains filtered or unexported fields
}
Bar represents a bar chart.
func (*Bar) EnablePolarType ¶
EnablePolarType enables the polar bar.
func (*Bar) XYReversal ¶
XYReversal checks if X axis and Y axis are reversed.
type Bar3D ¶
type Bar3D struct {
Chart3D
}
Bar3D represents a 3D bar chart.
func (*Bar3D) AddSeries ¶
func (c *Bar3D) AddSeries(name string, data []opts.Chart3DData, options ...SeriesOpts) *Bar3D
AddSeries adds the new series.
type BaseConfiguration ¶
type BaseConfiguration struct {
opts.Legend `json:"legend"`
opts.Tooltip `json:"tooltip"`
opts.Toolbox `json:"toolbox"`
opts.Title `json:"title"`
opts.Polar `json:"polar"`
opts.AngleAxis `json:"angleAxis"`
opts.RadiusAxis `json:"radiusAxis"`
opts.Brush `json:"brush"`
*opts.AxisPointer `json:"axisPointer"`
Calendar []*opts.Calendar `json:"calendar"`
render.Renderer `json:"-"`
opts.Initialization `json:"-"`
opts.Assets `json:"-"`
opts.RadarComponent `json:"-"`
opts.GeoComponent `json:"-"`
opts.ParallelComponent `json:"-"`
opts.JSFunctions `json:"-"`
opts.SingleAxis `json:"-"`
MultiSeries
XYAxis
opts.XAxis3D
opts.YAxis3D
opts.ZAxis3D
opts.Grid3D
opts.Grid
// Colors is the color list of palette.
// If no color is set in series, the colors would be adopted sequentially and circularly
// from this list as the colors of series.
Colors []string
// Animation configs
// Animation whether enable the animation, default true
Animation types.Bool `json:"animation,omitempty"`
AnimationThreshold types.Int `json:"animationThreshold,omitempty"`
// AnimationDuration defined as types.FuncStr for more flexibilities, so are other related options
AnimationDuration types.FuncStr `json:"animationDuration,omitempty"`
AnimationEasing string `json:"animationEasing,omitempty"`
AnimationDelay types.FuncStr `json:"animationDelay,omitempty"`
AnimationDurationUpdate types.FuncStr `json:"animationDurationUpdate,omitempty"`
AnimationEasingUpdate string `json:"animationEasingUpdate,omitempty"`
AnimationDelayUpdate types.FuncStr `json:"animationDelayUpdate,omitempty"`
//Progressive specifies the amount of graphic elements that can be rendered within a frame (about 16ms) if "progressive rendering" enabled.
//By default, progressive is auto-enabled when data amount is bigger than progressiveThreshold
Progressive types.Int `json:"progressive,omitempty"`
//ProgressiveThreshold number If current data amount is over the threshold, "progressive rendering" is enabled, default 3000
ProgressiveThreshold types.Int `json:"progressiveThreshold,omitempty"`
// Array of datasets, managed by AddDataset()
DatasetList []opts.Dataset `json:"dataset,omitempty"`
DataZoomList []opts.DataZoom `json:"datazoom,omitempty"`
VisualMapList []opts.VisualMap `json:"visualmap,omitempty"`
EventListeners []event.Listener `json:"-"`
// ParallelAxisList represents the component list which is the coordinate axis for parallel coordinate.
ParallelAxisList []opts.ParallelAxis
GridList []opts.Grid `json:"grid,omitempty"`
// contains filtered or unexported fields
}
BaseConfiguration represents an option set needed by all chart types.
func (*BaseConfiguration) Accept ¶
func (bc *BaseConfiguration) Accept(visitor ConfigurationVisitor)
func (*BaseConfiguration) AddDataset ¶
func (bc *BaseConfiguration) AddDataset(dataset ...opts.Dataset)
AddDataset adds a Dataset to this chart
func (*BaseConfiguration) FillDefaultValues ¶
func (bc *BaseConfiguration) FillDefaultValues()
FillDefaultValues fill default values for chart options.
func (*BaseConfiguration) GetAssets ¶
func (bc *BaseConfiguration) GetAssets() opts.Assets
GetAssets returns the Assets options.
func (*BaseConfiguration) JSON ¶
func (bc *BaseConfiguration) JSON() map[string]interface{}
JSON wraps all the options to a map so that it could be used in the base template
Get data in bytes bs, _ : = json.Marshal(bar.JSON())
func (*BaseConfiguration) JSONNotEscaped ¶
func (bc *BaseConfiguration) JSONNotEscaped() template.HTML
JSONNotEscaped works like method JSON, but it returns a marshaled object whose characters will not be escaped in the template
type BaseConfigurationVisitor ¶
type BaseConfigurationVisitor struct {
}
BaseConfigurationVisitor a default visitor, noop
func (BaseConfigurationVisitor) Visit ¶
func (b BaseConfigurationVisitor) Visit(chart map[string]interface{})
func (BaseConfigurationVisitor) VisitAngleAxis ¶
func (b BaseConfigurationVisitor) VisitAngleAxis(angleAxis opts.AngleAxis) interface{}
func (BaseConfigurationVisitor) VisitAxisPointer ¶
func (b BaseConfigurationVisitor) VisitAxisPointer(axisPointer *opts.AxisPointer) interface{}
func (BaseConfigurationVisitor) VisitBrush ¶
func (b BaseConfigurationVisitor) VisitBrush(brush opts.Brush) interface{}
func (BaseConfigurationVisitor) VisitCalendar ¶
func (b BaseConfigurationVisitor) VisitCalendar(calendar []*opts.Calendar) interface{}
func (BaseConfigurationVisitor) VisitDataZooms ¶
func (b BaseConfigurationVisitor) VisitDataZooms(dataZooms []opts.DataZoom) interface{}
func (BaseConfigurationVisitor) VisitDatasets ¶
func (b BaseConfigurationVisitor) VisitDatasets(datasets ...opts.Dataset) interface{}
func (BaseConfigurationVisitor) VisitGeo ¶
func (b BaseConfigurationVisitor) VisitGeo(geo opts.GeoComponent) interface{}
func (BaseConfigurationVisitor) VisitGrid ¶
func (b BaseConfigurationVisitor) VisitGrid(grid []opts.Grid) interface{}
func (BaseConfigurationVisitor) VisitGrid3D ¶
func (b BaseConfigurationVisitor) VisitGrid3D(grid3D opts.Grid3D) interface{}
func (BaseConfigurationVisitor) VisitLegendOpt ¶
func (b BaseConfigurationVisitor) VisitLegendOpt(legend opts.Legend) interface{}
func (BaseConfigurationVisitor) VisitParallel ¶
func (b BaseConfigurationVisitor) VisitParallel(parallel opts.ParallelComponent) interface{}
func (BaseConfigurationVisitor) VisitParallelAxis ¶
func (b BaseConfigurationVisitor) VisitParallelAxis(parallelAxes []opts.ParallelAxis) interface{}
func (BaseConfigurationVisitor) VisitPolar ¶
func (b BaseConfigurationVisitor) VisitPolar(polar opts.Polar) interface{}
func (BaseConfigurationVisitor) VisitRadar ¶
func (b BaseConfigurationVisitor) VisitRadar(radar opts.RadarComponent) interface{}
func (BaseConfigurationVisitor) VisitRadiusAxis ¶
func (b BaseConfigurationVisitor) VisitRadiusAxis(radiusAxis opts.RadiusAxis) interface{}
func (BaseConfigurationVisitor) VisitSeriesOpt ¶
func (b BaseConfigurationVisitor) VisitSeriesOpt(series MultiSeries) interface{}
func (BaseConfigurationVisitor) VisitSingleAxis ¶
func (b BaseConfigurationVisitor) VisitSingleAxis(singleAxis opts.SingleAxis) interface{}
func (BaseConfigurationVisitor) VisitTitleOpt ¶
func (b BaseConfigurationVisitor) VisitTitleOpt(title opts.Title) interface{}
func (BaseConfigurationVisitor) VisitToolbox ¶
func (b BaseConfigurationVisitor) VisitToolbox(toolbox opts.Toolbox) interface{}
func (BaseConfigurationVisitor) VisitTooltipOpt ¶
func (b BaseConfigurationVisitor) VisitTooltipOpt(tooltip opts.Tooltip) interface{}
func (BaseConfigurationVisitor) VisitVisualMaps ¶
func (b BaseConfigurationVisitor) VisitVisualMaps(visualMaps []opts.VisualMap) interface{}
func (BaseConfigurationVisitor) VisitXAxis ¶
func (b BaseConfigurationVisitor) VisitXAxis(xAxis []opts.XAxis) interface{}
func (BaseConfigurationVisitor) VisitXAxis3D ¶
func (b BaseConfigurationVisitor) VisitXAxis3D(xAxis3D opts.XAxis3D) interface{}
func (BaseConfigurationVisitor) VisitYAxis ¶
func (b BaseConfigurationVisitor) VisitYAxis(yAxis []opts.YAxis) interface{}
func (BaseConfigurationVisitor) VisitYAxis3D ¶
func (b BaseConfigurationVisitor) VisitYAxis3D(yAxis3D opts.YAxis3D) interface{}
func (BaseConfigurationVisitor) VisitZAxis3D ¶
func (b BaseConfigurationVisitor) VisitZAxis3D(zAxis3D opts.ZAxis3D) interface{}
type BoxPlot ¶
type BoxPlot struct {
RectChart
}
BoxPlot represents a boxplot chart.
func (*BoxPlot) AddSeries ¶
func (c *BoxPlot) AddSeries(name string, data []opts.BoxPlotData, options ...SeriesOpts) *BoxPlot
AddSeries adds the new series.
type Chart3D ¶
type Chart3D struct {
BaseConfiguration
}
Chart3D is a chart in 3D coordinates.
func (*Chart3D) SetGlobalOptions ¶
func (c *Chart3D) SetGlobalOptions(options ...GlobalOpts) *Chart3D
SetGlobalOptions sets options for the Chart3D instance.
type ConfigurationVisitor ¶
type ConfigurationVisitor interface {
// Visit called after all builtin options settled
Visit(chart map[string]interface{})
VisitTitleOpt(title opts.Title) interface{}
VisitLegendOpt(legend opts.Legend) interface{}
VisitTooltipOpt(tooltip opts.Tooltip) interface{}
VisitSeriesOpt(series MultiSeries) interface{}
VisitDatasets(datasets ...opts.Dataset) interface{}
VisitAxisPointer(axisPointer *opts.AxisPointer) interface{}
VisitPolar(polar opts.Polar) interface{}
VisitAngleAxis(angleAxis opts.AngleAxis) interface{}
VisitRadiusAxis(radiusAxis opts.RadiusAxis) interface{}
VisitGeo(geo opts.GeoComponent) interface{}
VisitRadar(radar opts.RadarComponent) interface{}
VisitParallel(parallel opts.ParallelComponent) interface{}
VisitParallelAxis(parallelAxes []opts.ParallelAxis) interface{}
VisitSingleAxis(singleAxis opts.SingleAxis) interface{}
VisitToolbox(toolbox opts.Toolbox) interface{}
VisitDataZooms(dataZooms []opts.DataZoom) interface{}
VisitVisualMaps(visualMaps []opts.VisualMap) interface{}
VisitXAxis(xAxis []opts.XAxis) interface{}
VisitYAxis(yAxis []opts.YAxis) interface{}
VisitGrid(grid []opts.Grid) interface{}
VisitXAxis3D(xAxis3D opts.XAxis3D) interface{}
VisitYAxis3D(yAxis3D opts.YAxis3D) interface{}
VisitZAxis3D(zAxis3D opts.ZAxis3D) interface{}
VisitGrid3D(grid3D opts.Grid3D) interface{}
VisitBrush(brush opts.Brush) interface{}
VisitCalendar(calendar []*opts.Calendar) interface{}
}
ConfigurationVisitor visitor, also the transformer. Allow to visit and modify/enhance chart options before rendering, even though the option structure isn't built-in.
type Custom ¶
type Custom struct {
RectChart
}
Custom represents a custom chart.
func (*Custom) AddSeries ¶
func (c *Custom) AddSeries(name string, data []opts.CustomData, options ...SeriesOpts) *Custom
AddSeries adds the new series.
type EffectScatter ¶
type EffectScatter struct {
RectChart
}
EffectScatter represents an effect scatter chart.
func NewEffectScatter ¶
func NewEffectScatter() *EffectScatter
NewEffectScatter creates a new effect scatter chart.
func (*EffectScatter) AddSeries ¶
func (c *EffectScatter) AddSeries(name string, data []opts.EffectScatterData, options ...SeriesOpts) *EffectScatter
AddSeries adds the Y axis.
func (*EffectScatter) SetXAxis ¶
func (c *EffectScatter) SetXAxis(x interface{}) *EffectScatter
SetXAxis adds the X axis.
func (*EffectScatter) Validate ¶
func (c *EffectScatter) Validate()
Validate validates the given configuration.
type Funnel ¶
type Funnel struct {
BaseConfiguration
}
Funnel represents a funnel chart.
func (*Funnel) AddSeries ¶
func (c *Funnel) AddSeries(name string, data []opts.FunnelData, options ...SeriesOpts) *Funnel
AddSeries adds new data sets.
func (*Funnel) SetGlobalOptions ¶
func (c *Funnel) SetGlobalOptions(options ...GlobalOpts) *Funnel
SetGlobalOptions sets options for the Funnel instance.
type Gauge ¶
type Gauge struct {
BaseConfiguration
}
Gauge represents a gauge chart.
func (*Gauge) SetGlobalOptions ¶
func (c *Gauge) SetGlobalOptions(options ...GlobalOpts) *Gauge
SetGlobalOptions sets options for the Gauge instance.
type Geo ¶
type Geo struct {
BaseConfiguration
}
Geo represents a geo chart.
func (*Geo) AddSeries ¶
AddSeries adds new data sets. geoType options: * types.ChartScatter * types.ChartEffectScatter * types.ChartHeatMap
func (*Geo) SetGlobalOptions ¶
func (c *Geo) SetGlobalOptions(options ...GlobalOpts) *Geo
SetGlobalOptions sets options for the Geo instance.
type GlobalOpts ¶
type GlobalOpts func(bc *BaseConfiguration)
GlobalOpts sets the Global options for charts.
func WithAngleAxisOps ¶
func WithAngleAxisOps(opt opts.AngleAxis) GlobalOpts
WithAngleAxisOps sets the angle of the axis.
func WithAnimation ¶
func WithAnimation(enable bool) GlobalOpts
WithAnimation enable or disable the animation.
func WithAxisPointerOpts ¶
func WithAxisPointerOpts(opt *opts.AxisPointer) GlobalOpts
WithAxisPointerOpts sets the axis pointer.
func WithColorsOpts ¶
func WithColorsOpts(opt opts.Colors) GlobalOpts
WithColorsOpts sets the color.
func WithDataZoomOpts ¶
func WithDataZoomOpts(opt ...opts.DataZoom) GlobalOpts
WithDataZoomOpts sets the list of the zoom data.
func WithEventListeners ¶
func WithEventListeners(listeners ...event.Listener) GlobalOpts
func WithGeoComponentOpts ¶
func WithGeoComponentOpts(opt opts.GeoComponent) GlobalOpts
WithGeoComponentOpts sets the geo component.
func WithGrid3DOpts ¶
func WithGrid3DOpts(opt opts.Grid3D) GlobalOpts
WithGrid3DOpts sets the grid of the Chart3D instance.
func WithGridOpts ¶
func WithGridOpts(opt ...opts.Grid) GlobalOpts
WithGridOpts sets the List of the grid.
func WithInitializationOpts ¶
func WithInitializationOpts(opt opts.Initialization) GlobalOpts
WithInitializationOpts sets the initialization.
func WithLegendOpts ¶
func WithLegendOpts(opt opts.Legend) GlobalOpts
WithLegendOpts sets the legend.
func WithParallelAxisList ¶
func WithParallelAxisList(opt []opts.ParallelAxis) GlobalOpts
WithParallelAxisList sets the list of the parallel axis.
func WithParallelComponentOpts ¶
func WithParallelComponentOpts(opt opts.ParallelComponent) GlobalOpts
WithParallelComponentOpts sets the parallel component.
func WithProgressive ¶
func WithProgressive(opt int) GlobalOpts
WithProgressive allows to set amount of graphic elements rendered in a frame
func WithProgressiveThreshold ¶
func WithProgressiveThreshold(opt int) GlobalOpts
WithProgressiveThreshold Allows to set treshold for progressive rendering
func WithRadarComponentOpts ¶
func WithRadarComponentOpts(opt opts.RadarComponent) GlobalOpts
WithRadarComponentOpts sets the component of the radar.
func WithRadiusAxisOps ¶
func WithRadiusAxisOps(opt opts.RadiusAxis) GlobalOpts
WithRadiusAxisOps sets the radius of the axis.
func WithSingleAxisOpts ¶
func WithSingleAxisOpts(opt opts.SingleAxis) GlobalOpts
WithSingleAxisOpts sets the single axis.
func WithToolboxOpts ¶
func WithToolboxOpts(opt opts.Toolbox) GlobalOpts
WithToolboxOpts sets the toolbox.
func WithTooltipOpts ¶
func WithTooltipOpts(opt opts.Tooltip) GlobalOpts
WithTooltipOpts sets the tooltip.
func WithVisualMapOpts ¶
func WithVisualMapOpts(opt ...opts.VisualMap) GlobalOpts
WithVisualMapOpts sets the List of the visual map.
func WithXAxis3DOpts ¶
func WithXAxis3DOpts(opt opts.XAxis3D) GlobalOpts
WithXAxis3DOpts sets the X axis of the Chart3D instance.
func WithXAxisOpts ¶
func WithXAxisOpts(opt opts.XAxis, index ...int) GlobalOpts
WithXAxisOpts sets the X axis.
func WithYAxis3DOpts ¶
func WithYAxis3DOpts(opt opts.YAxis3D) GlobalOpts
WithYAxis3DOpts sets the Y axis of the Chart3D instance.
func WithYAxisOpts ¶
func WithYAxisOpts(opt opts.YAxis, index ...int) GlobalOpts
WithYAxisOpts sets the Y axis.
func WithZAxis3DOpts ¶
func WithZAxis3DOpts(opt opts.ZAxis3D) GlobalOpts
WithZAxis3DOpts sets the Z axis of the Chart3D instance.
type Graph ¶
type Graph struct {
BaseConfiguration
}
Graph represents a graph chart.
func (*Graph) AddSeries ¶
func (c *Graph) AddSeries(name string, nodes []opts.GraphNode, links []opts.GraphLink, options ...SeriesOpts) *Graph
AddSeries adds the new series.
func (*Graph) SetGlobalOptions ¶
func (c *Graph) SetGlobalOptions(options ...GlobalOpts) *Graph
SetGlobalOptions sets options for the Graph instance.
type HeatMap ¶
type HeatMap struct {
RectChart
}
HeatMap represents a heatmap chart.
func (*HeatMap) AddCalendar ¶
AddCalendar adds the calendar configuration to the chart.
func (*HeatMap) AddSeries ¶
func (c *HeatMap) AddSeries(name string, data []opts.HeatMapData, options ...SeriesOpts) *HeatMap
AddSeries adds the new series.
type Kline ¶
type Kline struct {
RectChart
}
Kline represents a kline chart.
type Line ¶
type Line struct {
RectChart
}
Line represents a line chart.
type Line3D ¶
type Line3D struct {
Chart3D
}
Line3D represents a 3D line chart.
func (*Line3D) AddSeries ¶
func (c *Line3D) AddSeries(name string, data []opts.Chart3DData, options ...SeriesOpts) *Line3D
AddSeries adds the new series.
type Liquid ¶
type Liquid struct {
BaseConfiguration
}
Liquid represents a liquid chart.
func (*Liquid) AddSeries ¶
func (c *Liquid) AddSeries(name string, data []opts.LiquidData, options ...SeriesOpts) *Liquid
AddSeries adds new data sets.
func (*Liquid) SetGlobalOptions ¶
func (c *Liquid) SetGlobalOptions(options ...GlobalOpts) *Liquid
SetGlobalOptions sets options for the Liquid instance.
type Map ¶
type Map struct {
BaseConfiguration
// contains filtered or unexported fields
}
Map represents a map chart.
func (*Map) RegisterMapType ¶
RegisterMapType registers the given mapType.
func (*Map) SetGlobalOptions ¶
func (c *Map) SetGlobalOptions(options ...GlobalOpts) *Map
SetGlobalOptions sets options for the Map instance.
type MultiSeries ¶
type MultiSeries []SingleSeries
MultiSeries represents multiple series.
func (*MultiSeries) SetSeriesOptions ¶
func (ms *MultiSeries) SetSeriesOptions(opts ...SeriesOpts)
SetSeriesOptions sets options for all the series. NOTE: It should be called after AddSeries, otherwise, the Options is no place to add on. Previous options will be overwritten every time hence setting them on the `AddSeries` if you want to customize each series individually
here -> ↓ <-
func (c *Bar) AddSeries(name string, data []opts.BarData, options ...SeriesOpts)
type Parallel ¶
type Parallel struct {
BaseConfiguration
}
Parallel represents a parallel axis.
func (*Parallel) AddSeries ¶
func (c *Parallel) AddSeries(name string, data []opts.ParallelData, options ...SeriesOpts) *Parallel
AddSeries adds new data sets.
func (*Parallel) SetGlobalOptions ¶
func (c *Parallel) SetGlobalOptions(options ...GlobalOpts) *Parallel
SetGlobalOptions sets options for the Parallel instance.
type Pie ¶
type Pie struct {
BaseConfiguration
}
Pie represents a pie chart.
func (*Pie) SetGlobalOptions ¶
func (c *Pie) SetGlobalOptions(options ...GlobalOpts) *Pie
SetGlobalOptions sets options for the Pie instance.
type Radar ¶
type Radar struct {
BaseConfiguration
// SymbolKeepAspect is whether to keep aspect for symbols in the form of path://.
SymbolKeepAspect types.Bool
}
Radar represents a radar chart.
func (*Radar) SetGlobalOptions ¶
func (c *Radar) SetGlobalOptions(options ...GlobalOpts) *Radar
SetGlobalOptions sets options for the Radar instance.
type RectAggregator ¶
RectAggregator is a binary operator for the RectChart merge function
type RectChart ¶
type RectChart struct {
RectConfiguration
// contains filtered or unexported fields
}
RectChart is a chart in RectChart coordinate.
func (*RectChart) Aggregate ¶
func (rc *RectChart) Aggregate(aggregator RectAggregator, charts ...Overlaper)
Aggregate aggregation multiple rect charts into one single canvas. An aggregator will merge all charts in orders into the final one. It is only suited for some of the charts which are in rectangular coordinate.
func (*RectChart) Overlap ¶
Overlap composes multiple charts' Series data into one single canvas. It is only suited for some of the charts which are in rectangular coordinate. Supported charts: Bar/BoxPlot/Line/Scatter/EffectScatter/Kline/HeatMap/Custom
func (*RectChart) SetGlobalOptions ¶
func (rc *RectChart) SetGlobalOptions(options ...GlobalOpts) *RectChart
SetGlobalOptions sets options for the RectChart instance.
type RectConfiguration ¶
type RectConfiguration struct {
BaseConfiguration
}
RectConfiguration contains options for the rectangular coordinates.
type Sankey ¶
type Sankey struct {
BaseConfiguration
}
Sankey represents a sankey chart.
func (*Sankey) AddSeries ¶
func (c *Sankey) AddSeries(name string, nodes []opts.SankeyNode, links []opts.SankeyLink, options ...SeriesOpts) *Sankey
AddSeries adds new data sets.
func (*Sankey) SetGlobalOptions ¶
func (c *Sankey) SetGlobalOptions(options ...GlobalOpts) *Sankey
SetGlobalOptions sets options for the Sankey instance.
type Scatter ¶
type Scatter struct {
RectChart
}
Scatter represents a scatter chart.
func (*Scatter) AddSeries ¶
func (c *Scatter) AddSeries(name string, data []opts.ScatterData, options ...SeriesOpts) *Scatter
AddSeries adds the new series.
type Scatter3D ¶
type Scatter3D struct {
Chart3D
}
Scatter3D represents a 3D scatter chart.
func (*Scatter3D) AddSeries ¶
func (c *Scatter3D) AddSeries(name string, data []opts.Chart3DData, options ...SeriesOpts) *Scatter3D
AddSeries adds the new series.
type SeriesOpts ¶
type SeriesOpts func(s *SingleSeries)
func WithAnimationOpts ¶
func WithAnimationOpts(opt opts.Animation) SeriesOpts
func WithAreaStyleOpts ¶
func WithAreaStyleOpts(opt opts.AreaStyle) SeriesOpts
WithAreaStyleOpts sets the area style.
func WithBar3DChartOpts ¶
func WithBar3DChartOpts(opt opts.Bar3DChart) SeriesOpts
WithBar3DChartOpts sets the Bar3DChart option.
func WithBarChartOpts ¶
func WithBarChartOpts(opt opts.BarChart) SeriesOpts
WithBarChartOpts sets the BarChart option.
func WithCalendarIndex ¶
func WithCalendarIndex(index int) SeriesOpts
func WithCircularStyleOpts ¶
func WithCircularStyleOpts(opt opts.CircularStyle) SeriesOpts
WithCircularStyleOpts With CircularStyle Opts
func WithCoordinateSystem ¶
func WithCoordinateSystem(cs string) SeriesOpts
func WithCustomChartOpts ¶
func WithCustomChartOpts(opt opts.CustomChart) SeriesOpts
WithCustomChartOpts sets the CustomChart option.
func WithDatasetIndex ¶
func WithDatasetIndex(index int) SeriesOpts
WithDatasetIndex sets the datasetIndex option.
func WithEffectScatterChartOpts ¶
func WithEffectScatterChartOpts(opt opts.EffectScatterChart) SeriesOpts
WithEffectScatterChartOpts sets the ScatterChart option.
func WithEmphasisOpts ¶
func WithEmphasisOpts(opt opts.Emphasis) SeriesOpts
WithEmphasisOpts sets the emphasis.
func WithEncodeOpts ¶
func WithEncodeOpts(opt opts.Encode) SeriesOpts
WithEncodeOpts Set encodes for dataSets
func WithGraphChartOpts ¶
func WithGraphChartOpts(opt opts.GraphChart) SeriesOpts
WithGraphChartOpts sets the GraphChart option.
func WithHeatMapChartOpts ¶
func WithHeatMapChartOpts(opt opts.HeatMapChart) SeriesOpts
WithHeatMapChartOpts sets the HeatMapChart option.
func WithItemStyleOpts ¶
func WithItemStyleOpts(opt opts.ItemStyle) SeriesOpts
WithItemStyleOpts sets the item style.
func WithKlineChartOpts ¶
func WithKlineChartOpts(opt opts.KlineChart) SeriesOpts
WithLineChartOpts sets the LineChart option.
func WithLineChartOpts ¶
func WithLineChartOpts(opt opts.LineChart) SeriesOpts
WithLineChartOpts sets the LineChart option.
func WithLineStyleOpts ¶
func WithLineStyleOpts(opt opts.LineStyle) SeriesOpts
WithLineStyleOpts sets the line style.
func WithLiquidChartOpts ¶
func WithLiquidChartOpts(opt opts.LiquidChart) SeriesOpts
WithLiquidChartOpts sets the LiquidChart option.
func WithMarkAreaData ¶
func WithMarkAreaData(datas ...[]opts.MarkAreaData) SeriesOpts
WithMarkAreaData sets the markArea.data each item as array See https://echarts.apache.org/en/option.html#series-candlestick.markArea.data
func WithMarkAreaData0 ¶
func WithMarkAreaData0(data0 opts.MarkAreaData0) SeriesOpts
WithMarkAreaData0 sets the markArea.data.0
func WithMarkAreaData1 ¶
func WithMarkAreaData1(data1 opts.MarkAreaData1) SeriesOpts
WithMarkAreaData1 sets the markArea.data.1
func WithMarkAreaNameCoordItemOpts ¶
func WithMarkAreaNameCoordItemOpts(opt ...opts.MarkAreaNameCoordItem) SeriesOpts
WithMarkAreaNameCoordItemOpts sets the coordinates of the MarkLine.
func WithMarkAreaNameTypeItemOpts ¶
func WithMarkAreaNameTypeItemOpts(opt ...opts.MarkAreaNameTypeItem) SeriesOpts
WithMarkAreaNameTypeItemOpts sets the type of the MarkArea.
func WithMarkAreaNameXAxisItemOpts ¶
func WithMarkAreaNameXAxisItemOpts(opt ...opts.MarkAreaNameXAxisItem) SeriesOpts
WithMarkAreaNameXAxisItemOpts sets the X axis of the MarkLine.
func WithMarkAreaNameYAxisItemOpts ¶
func WithMarkAreaNameYAxisItemOpts(opt ...opts.MarkAreaNameYAxisItem) SeriesOpts
WithMarkAreaNameYAxisItemOpts sets the Y axis of the MarkLine.
func WithMarkAreaStyleOpts ¶
func WithMarkAreaStyleOpts(opt opts.MarkAreaStyle) SeriesOpts
WithMarkAreaStyleOpts sets the style of the MarkArea.
func WithMarkLineNameCoordItemOpts ¶
func WithMarkLineNameCoordItemOpts(opt ...opts.MarkLineNameCoordItem) SeriesOpts
WithMarkLineNameCoordItemOpts sets the coordinates of the MarkLine.
func WithMarkLineNameTypeItemOpts ¶
func WithMarkLineNameTypeItemOpts(opt ...opts.MarkLineNameTypeItem) SeriesOpts
WithMarkLineNameTypeItemOpts sets the type of the MarkLine.
func WithMarkLineNameXAxisItemOpts ¶
func WithMarkLineNameXAxisItemOpts(opt ...opts.MarkLineNameXAxisItem) SeriesOpts
WithMarkLineNameXAxisItemOpts sets the X axis of the MarkLine.
func WithMarkLineNameYAxisItemOpts ¶
func WithMarkLineNameYAxisItemOpts(opt ...opts.MarkLineNameYAxisItem) SeriesOpts
WithMarkLineNameYAxisItemOpts sets the Y axis of the MarkLine.
func WithMarkLineStyleOpts ¶
func WithMarkLineStyleOpts(opt opts.MarkLineStyle) SeriesOpts
WithMarkLineStyleOpts sets the style of the MarkLine.
func WithMarkPointNameCoordItemOpts ¶
func WithMarkPointNameCoordItemOpts(opt ...opts.MarkPointNameCoordItem) SeriesOpts
WithMarkPointNameCoordItemOpts sets the coordinated of the MarkPoint.
func WithMarkPointNameTypeItemOpts ¶
func WithMarkPointNameTypeItemOpts(opt ...opts.MarkPointNameTypeItem) SeriesOpts
WithMarkPointNameTypeItemOpts sets the type of the MarkPoint.
func WithMarkPointStyleOpts ¶
func WithMarkPointStyleOpts(opt opts.MarkPointStyle) SeriesOpts
WithMarkPointStyleOpts sets the style of the MarkPoint.
func WithPieChartOpts ¶
func WithPieChartOpts(opt opts.PieChart) SeriesOpts
WithPieChartOpts sets the PieChart option.
func WithRadarChartOpts ¶
func WithRadarChartOpts(opt opts.RadarChart) SeriesOpts
WithRadarChartOpts sets the RadarChart option.
func WithRippleEffectOpts ¶
func WithRippleEffectOpts(opt opts.RippleEffect) SeriesOpts
WithRippleEffectOpts sets the ripple effect.
func WithScatterChartOpts ¶
func WithScatterChartOpts(opt opts.ScatterChart) SeriesOpts
WithScatterChartOpts sets the ScatterChart option.
func WithSeriesAnimation ¶
func WithSeriesAnimation(enable bool) SeriesOpts
func WithSeriesOpts ¶
func WithSeriesOpts(opf SingleSeriesOptFunc) SeriesOpts
WithSeriesOpts If the WithXXX helper method is not good enough, use this directly!
func WithSeriesSymbolKeepAspect ¶
func WithSeriesSymbolKeepAspect(enable bool) SeriesOpts
func WithSunburstOpts ¶
func WithSunburstOpts(opt opts.SunburstChart) SeriesOpts
WithSunburstOpts sets the SunburstChart option.
func WithTreeMapOpts ¶
func WithTreeMapOpts(opt opts.TreeMapChart) SeriesOpts
WithTreeMapOpts sets the TreeMapChart options.
func WithTreeOpts ¶
func WithTreeOpts(opt opts.TreeChart) SeriesOpts
WithTreeOpts sets the TreeChart option.
func WithWorldCloudChartOpts ¶
func WithWorldCloudChartOpts(opt opts.WordCloudChart) SeriesOpts
WithWorldCloudChartOpts sets the WorldCloudChart option.
type SingleSeries ¶
type SingleSeries struct {
Name string `json:"name,omitempty"`
Type string `json:"type,omitempty"`
// Rectangular charts
// Line | Bar
Stack string `json:"stack,omitempty"`
// Line | Bar | Scatter
XAxisIndex int `json:"xAxisIndex,omitempty"`
// Line | Bar | Scatter
YAxisIndex int `json:"yAxisIndex,omitempty"`
// Bar
BarGap string `json:"barGap,omitempty"`
// Bar
BarCategoryGap string `json:"barCategoryGap,omitempty"`
// Bar
ShowBackground types.Bool `json:"showBackground,omitempty"`
// Bar
RoundCap types.Bool `json:"roundCap,omitempty"`
// Bar3D
Shading string `json:"shading,omitempty"`
// Graph
Links interface{} `json:"links,omitempty"`
Layout string `json:"layout,omitempty"`
Force interface{} `json:"force,omitempty"`
Categories interface{} `json:"categories,omitempty"`
Roam types.Bool `json:"roam,omitempty"`
EdgeSymbol interface{} `json:"edgeSymbol,omitempty"`
EdgeSymbolSize interface{} `json:"edgeSymbolSize,omitempty"`
EdgeLabel interface{} `json:"edgeLabel,omitempty"`
Draggable types.Bool `json:"draggable,omitempty"`
FocusNodeAdjacency types.Bool `json:"focusNodeAdjacency,omitempty"`
// Line | Radar
SymbolKeepAspect types.Bool `json:"symbolKeepAspect,omitempty"`
// BarWidth The width options of the bar. Adaptive when not specified.
// Can be an absolute value like 40 or a percent value like '60%'.
// Configurable charts: bar | kline
BarWidth string `json:"barWidth,omitempty"`
BarMinWidth string `json:"barMinWidth,omitempty"`
BarMaxWidth string `json:"barMaxWidth,omitempty"`
// Line | Bar | Pie | Scatter | Radar
ColorBy string `json:"colorBy,omitempty"`
// Line | Bar
PolarIndex int `json:"polarIndex,omitempty"`
// Line
Step interface{} `json:"step,omitempty"`
// Line
Smooth types.Bool `json:"smooth,omitempty"`
// Line
ConnectNulls types.Bool `json:"connectNulls,omitempty"`
// Line
ShowSymbol types.Bool `json:"showSymbol,omitempty"`
// Line | Scatter | Radar
Symbol string `json:"symbol,omitempty"`
Color string `json:"color,omitempty"`
// Liquid
IsLiquidOutline types.Bool `json:"outline,omitempty"`
IsWaveAnimation types.Bool `json:"waveAnimation,omitempty"`
// Map
MapType string `json:"map,omitempty"`
// Map | Line | Bar | Pie | Scatter
CoordSystem string `json:"coordinateSystem,omitempty"`
// Pie
RoseType string `json:"roseType,omitempty"`
// Pie
Center interface{} `json:"center,omitempty"`
// Pie
Radius interface{} `json:"radius,omitempty"`
// Line | Scatter | Radar
SymbolSize interface{} `json:"symbolSize,omitempty"`
// Tree
Orient string `json:"orient,omitempty"`
ExpandAndCollapse types.Bool `json:"expandAndCollapse,omitempty"`
InitialTreeDepth int `json:"initialTreeDepth,omitempty"`
Leaves interface{} `json:"leaves,omitempty"`
Left string `json:"left,omitempty"`
Right string `json:"right,omitempty"`
Top string `json:"top,omitempty"`
Bottom string `json:"bottom,omitempty"`
// Radar
RadarIndex int `json:"radarIndex,omitempty"`
// TreeMap
LeafDepth int `json:"leafDepth,omitempty"`
Levels interface{} `json:"levels,omitempty"`
UpperLabel interface{} `json:"upperLabel,omitempty"`
// WordCloud
Shape string `json:"shape,omitempty"`
SizeRange []float32 `json:"sizeRange,omitempty"`
RotationRange []float32 `json:"rotationRange,omitempty"`
// Sunburst
NodeClick string `json:"nodeClick,omitempty"`
Sort string `json:"sort,omitempty"`
// Custom
RenderItem types.FuncStr `json:"renderItem,omitempty"`
// series data
Data interface{} `json:"data,omitempty"`
DatasetIndex int `json:"datasetIndex,omitempty"`
// Gauge
Progress *opts.Progress `json:"progress,omitempty"`
AxisTick *opts.AxisTick `json:"axisTick,omitempty"`
AxisLabel *opts.AxisLabel `json:"axisLabel,omitempty"`
AxisLine *opts.AxisLine `json:"axisLine,omitempty"`
Pointer *opts.Pointer `json:"pointer,omitempty"`
SplitLine *opts.SplitLine `json:"splitLine,omitempty"`
Detail *opts.Detail `json:"detail,omitempty"`
Title *opts.Title `json:"title,omitempty"`
Min int `json:"min,omitempty"`
Max int `json:"max,omitempty"`
StartAngle float64 `json:"startAngle,omitempty"`
EndAngle float64 `json:"endAngle,omitempty"`
Large types.Bool `json:"large,omitempty"`
LargeThreshold int `json:"largeThreshold,omitempty"`
HoverLayerThreshold int `json:"hoverLayerThreshold,omitempty"`
UseUTC types.Bool `json:"useUTC,omitempty"`
// Animation related configs
Animation types.Bool `json:"animation,omitempty"`
AnimationThreshold int `json:"animationThreshold,omitempty"`
AnimationDuration int `json:"animationDuration,omitempty"`
AnimationEasing string `json:"animationEasing,omitempty"`
AnimationDelay int `json:"animationDelay,omitempty"`
AnimationDurationUpdate int `json:"animationDurationUpdate,omitempty"`
AnimationEasingUpdate string `json:"animationEasingUpdate,omitempty"`
AnimationDelayUpdate int `json:"animationDelayUpdate,omitempty"`
RenderLabelForZeroData types.Bool `json:"renderLabelForZeroData,omitempty"`
SelectedMode types.Bool `json:"selectedMode,omitempty"`
// series options
*opts.Encode `json:"encode,omitempty"`
*opts.ItemStyle `json:"itemStyle,omitempty"`
*opts.Label `json:"label,omitempty"`
*opts.LabelLine `json:"labelLine,omitempty"`
*opts.Emphasis `json:"emphasis,omitempty"`
*opts.MarkLines `json:"markLine,omitempty"`
*opts.MarkAreas `json:"markArea,omitempty"`
*opts.MarkPoints `json:"markPoint,omitempty"`
*opts.RippleEffect `json:"rippleEffect,omitempty"`
*opts.LineStyle `json:"lineStyle,omitempty"`
*opts.AreaStyle `json:"areaStyle,omitempty"`
*opts.TextStyle `json:"textStyle,omitempty"`
*opts.CircularStyle `json:"circular,omitempty"`
// Calendar
CalendarIndex int `json:"calendarIndex,omitempty"`
}
func (*SingleSeries) ConfigureSeriesOpts ¶
func (s *SingleSeries) ConfigureSeriesOpts(options ...SeriesOpts)
func (*SingleSeries) InitSeriesDefaultOpts ¶
func (s *SingleSeries) InitSeriesDefaultOpts(c BaseConfiguration)
type SingleSeriesOptFunc ¶
type SingleSeriesOptFunc func(s *SingleSeries)
type Sunburst ¶
type Sunburst struct {
BaseConfiguration
}
Sunburst represents a sunburst chart.
func (*Sunburst) AddSeries ¶
func (c *Sunburst) AddSeries(name string, data []opts.SunBurstData, options ...SeriesOpts) *Sunburst
AddSeries adds new data sets.
func (*Sunburst) SetGlobalOptions ¶
func (c *Sunburst) SetGlobalOptions(options ...GlobalOpts) *Sunburst
SetGlobalOptions sets options for the Pie instance.
type Surface3D ¶
type Surface3D struct {
Chart3D
}
Surface3D represents a 3D surface chart.
func (*Surface3D) AddSeries ¶
func (c *Surface3D) AddSeries(name string, data []opts.Chart3DData, options ...SeriesOpts) *Surface3D
AddSeries adds the new series.
type ThemeRiver ¶
type ThemeRiver struct {
BaseConfiguration
}
ThemeRiver represents a theme river chart.
func NewThemeRiver ¶
func NewThemeRiver() *ThemeRiver
NewThemeRiver creates a new theme river chart.
func (*ThemeRiver) AddSeries ¶
func (c *ThemeRiver) AddSeries(name string, data []opts.ThemeRiverData, options ...SeriesOpts) *ThemeRiver
AddSeries adds new data sets.
func (*ThemeRiver) SetGlobalOptions ¶
func (c *ThemeRiver) SetGlobalOptions(options ...GlobalOpts) *ThemeRiver
SetGlobalOptions sets options for the ThemeRiver instance.
func (*ThemeRiver) Validate ¶
func (c *ThemeRiver) Validate()
Validate validates the given configuration.
type Tree ¶
type Tree struct {
BaseConfiguration
}
Tree represents a Tree chart.
func (*Tree) SetGlobalOptions ¶
func (c *Tree) SetGlobalOptions(options ...GlobalOpts) *Tree
SetGlobalOptions sets options for the Tree instance.
type TreeMap ¶
type TreeMap struct {
BaseConfiguration
}
TreeMap represents a TreeMap chart.
func (*TreeMap) AddSeries ¶
func (c *TreeMap) AddSeries(name string, data []opts.TreeMapNode, options ...SeriesOpts) *TreeMap
AddSeries adds new data sets.
func (*TreeMap) SetGlobalOptions ¶
func (c *TreeMap) SetGlobalOptions(options ...GlobalOpts) *TreeMap
SetGlobalOptions sets options for the TreeMap instance.
type WordCloud ¶
type WordCloud struct {
BaseConfiguration
}
WordCloud represents a word cloud chart.
func (*WordCloud) AddSeries ¶
func (c *WordCloud) AddSeries(name string, data []opts.WordCloudData, options ...SeriesOpts) *WordCloud
AddSeries adds new data sets.
func (*WordCloud) SetGlobalOptions ¶
func (c *WordCloud) SetGlobalOptions(options ...GlobalOpts) *WordCloud
SetGlobalOptions sets options for the WordCloud instance.
type XYAxis ¶
XYAxis represent the X and Y axis in the rectangular coordinates.
func (*XYAxis) ExtendXAxis ¶
ExtendXAxis adds new X axes.
func (*XYAxis) ExtendYAxis ¶
ExtendYAxis adds new Y axes.