Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Charter ¶
type Charter interface {
Type() string
GetAssets() opts.Assets
// FillDefaultValues fill default values and would be overridden if any struct fields has been manually set
FillDefaultValues()
// Validate a validator as well as a post processor before render
Validate()
}
Charter represents a chart value which provides its type, assets and can be validated.
type Page ¶
type Page struct {
render.Renderer
opts.PageConfiguration
opts.Assets
Charts []Charter
Layout Layout
}
Page represents a page chart.
func (*Page) SetAssetsHost ¶
func (*Page) SetPageTitle ¶
Click to show internal directories.
Click to hide internal directories.